@@ -1,3 +1,5 @@
+import django
+
 from django.utils.module_loading import autodiscover_modules
 
 from .documents import Document  # noqa
@@ -11,4 +13,5 @@ def autodiscover():
     autodiscover_modules('documents')
 
 
-default_app_config = 'django_elasticsearch_dsl.apps.DEDConfig'
+if django.VERSION < (3, 2):
+    default_app_config = 'django_elasticsearch_dsl.apps.DEDConfig'
